@@ -607,7 +607,7 @@ class TestLocalMachine:
 
     @skip_on_windows
     def test_modifiers(self):
-        from plumbum.cmd import grep, ls
+        from plumbum.cmd import cat, grep, ls
 
         f = (ls["-a"] | grep["\\.py"]) & BG
         f.wait()
@@ -615,11 +615,17 @@ class TestLocalMachine:
 
         command = ls["-a"] | grep["local"]
         command_false = ls["-a"] | grep["not_a_file_here"]
+        command_false_2 = command_false | cat
         command & FG
         assert command & TF
         assert not (command_false & TF)
+        assert not (command_false_2 & TF)
         assert command & RETCODE == 0
         assert command_false & RETCODE == 1
+        assert command_false_2 & RETCODE == 1
+        assert (command & TEE)[0] == 0
+        assert (command_false & TEE(retcode=None))[0] == 1
+        assert (command_false_2 & TEE(retcode=None))[0] == 1
 
     @skip_on_windows
     def test_tee_modifier(self, capfd):
@@ -902,16 +908,14 @@ except PidFileTaken:
         num_of_procs = 20
         num_of_increments = 20
 
-        code = """from plumbum.fs.atomic import AtomicCounterFile
+        code = f"""from plumbum.fs.atomic import AtomicCounterFile
 import time
 time.sleep(0.2)
 afc = AtomicCounterFile.open("counter")
-for _ in range({}):
+for _ in range({num_of_increments}):
     print(afc.next())
     time.sleep(0.1)
-""".format(
-            num_of_increments,
-        )
+"""
 
         procs = []
         for _ in range(num_of_procs):
@@ -1048,10 +1052,6 @@ class TestLocalEncoding:
     except NameError:
         richstr = chr(40960)
 
-    @pytest.mark.xfail(
-        IS_WIN32,
-        reason="Unicode output on Windows does not work (Python 3.6+ was supposed to work)",
-    )
     def test_inout_rich(self):
         from plumbum.cmd import echo
 
