@@ -528,14 +528,12 @@ s.close()
                     assert_is_port(tun.dport)
                 assert tun.reverse
 
-                remote_send_af_inet = """import socket
+                remote_send_af_inet = f"""import socket
 s = socket.socket()
-s.connect(("localhost", {}))
-s.send("{}".encode("ascii"))
+s.connect(("localhost", {tun.dport}))
+s.send("{message}".encode("ascii"))
 s.close()
-""".format(
-                    tun.dport, message
-                )
+"""
                 (rem.python["-u"] << remote_send_af_inet).popen()
                 tunnel_server.join(timeout=1)
                 assert queue.get() == message
@@ -638,11 +636,11 @@ class TestParamikoMachine(BaseRemoteMachineTest):
         with self._connect() as rem:
             unicode_half = b"\xc2\xbd".decode("utf8")
 
-            ret = rem["bash"]("-c", 'echo -e "\xC2\xBD"')
-            assert ret == "%s\n" % unicode_half
+            ret = rem["bash"]("-c", 'echo -e "\xc2\xbd"')
+            assert ret == f"{unicode_half}\n"
 
-            ret = list(rem["bash"]["-c", 'echo -e "\xC2\xBD"'].popen())
-            assert ret == [["%s\n" % unicode_half, None]]
+            ret = list(rem["bash"]["-c", 'echo -e "\xc2\xbd"'].popen())
+            assert ret == [[f"{unicode_half}\n", None]]
 
     def test_path_open_remote_write_local_read(self):
         with self._connect() as rem:
